import sys
import os
import unittest
import json

sys.path.append(os.path.join(os.getcwd(), '..'))
from common.variables import USER, ACCOUNT_NAME, TIME, ACTION, PRESENCE, \
    ENCODING, RESPONSE, ERROR
from common.utils import get_message, send_message


class TestSocket:
    def __init__(self, test_message):
        self.test_message = test_message
        self.encoded_message = None

    def recv(self, max_length):
        json_message = json.dumps(self.test_message)
        return json_message.encode(ENCODING)

    def send(self, message):
        json_message = json.dumps(self.test_message)
        self.encoded_message = json_message.encode(ENCODING)


class TestUtilsClass(unittest.TestCase):
    test_message = {
        ACTION: PRESENCE,
        TIME: 1.1,
        USER: {
            ACCOUNT_NAME: 'test'
        }
    }
    success_dict = {RESPONSE: 200}
    error_dict = {RESPONSE: 400, ERROR: 'Bad Request'}

    def setUp(self) -> None:
        pass

    def tearDown(self) -> None:
        pass

    def test_get_message_returns_type_dict(self):
        test_socket = TestSocket(self.test_message)
        response = get_message(test_socket)
        self.assertIsInstance(response, dict)

    def test_get_message_response_equals(self):
        test_socket = TestSocket(self.test_message)
        response = get_message(test_socket)
        self.assertDictEqual(response, self.test_message)

    def test_send_message_raises_type_error(self):
        test_socket = TestSocket(self.test_message)
        self.assertRaises(
            TypeError,
            send_message,
            (test_socket, self.test_message)
        )

    def test_send_message_encoding(self):
        test_socket = TestSocket(self.test_message)
        send_message(test_socket, self.test_message)
        sended_message = json.loads(test_socket.encoded_message)
        self.assertDictEqual(sended_message, self.test_message)

    if __name__ == '__main__':
        unittest.main()


import unittest
import os
import sys

sys.path.append(os.path.join(os.getcwd(), '..'))
from common.variables import ACTION, PRESENCE, TIME, USER, ACCOUNT_NAME, \
    ERROR, RESPONSE
from server import process_client_message
from copy import deepcopy


class TestServerClass(unittest.TestCase):
    test_time = 1.1
    success_dict = {RESPONSE: 200}
    error_dict = {RESPONSE: 400, ERROR: 'Bad Request'}
    test_message = {
        ACTION: PRESENCE,
        TIME: test_time,
        USER: {
            ACCOUNT_NAME: 'Guest'
        }
    }

    def setUp(self) -> None:
        pass

    def tearDown(self) -> None:
        pass

    def test_process_client_message_success(self):
        response = process_client_message(self.test_message)
        self.assertDictEqual(response, self.success_dict)

    def test_process_client_message_wrong_action(self):
        message = deepcopy(self.test_message)
        message[ACTION] = 'wrong_action'
        response = process_client_message(message)
        self.assertDictEqual(response, self.error_dict)

    def test_process_client_message_without_time(self):
        message = deepcopy(self.test_message)
        message[TIME] = None
        response = process_client_message(message)
        self.assertDictEqual(response, self.error_dict)

    def test_process_client_message_without_user(self):
        message = deepcopy(self.test_message)
        message[USER] = None
        response = process_client_message(message)
        self.assertDictEqual(response, self.error_dict)

    def test_process_client_message_wrong_account_name(self):
        message = deepcopy(self.test_message)
        message[USER][ACCOUNT_NAME] = 'not_guest'
        response = process_client_message(message)
        self.assertDictEqual(response, self.error_dict)

    if __name__ == '__main__':
        unittest.main()


from setuptools import setup, find_packages

setup(name="xartiou_csa_client",
      version="0.0.0",
      description="Client Server APP client_side",
      author="Ivan Xartiou",
      author_email="xartiou@gmail.com",
      packages=find_packages(),
      install_requires=['PyQt5', 'sqlalchemy', 'pycryptodome', 'pycryptodomex']
      )


import inspect
import logging
import os.path
import sys
import traceback

if sys.argv[0].find('client.py') == -1:
    logger = logging.getLogger('server')
else:
    logger = logging.getLogger('client')

formatter = logging.Formatter("%(asctime)s - %(levelname)-8s - %(module)-8s - %(message)s ")

level_handler = logging.DEBUG
Level_logging = logging.DEBUG


def create_dir():
    storage_name = '../log/log_storage'
    if not os.path.exists(storage_name):
        os.mkdir(storage_name)
    return storage_name


def log(func):
    # @wraps(func)
    def log_saver(*args, **kwargs):
        ret = func(*args, **kwargs)
        logger.debug(f'Была вызвана функция {func.__name__} c параметрами {args}, {kwargs}. '
                     f'Вызов из модуля {func.__module__}.'
                     f'Вызов из функции {traceback.format_stack()[0].strip().split()[-1]}.'
                     f'Вызов из функции {inspect.stack()[1][3]}')

        return ret

    return log_saver
